@@ -6,10 +6,10 @@ import os
 
 class LoggingMiddleware(Middleware):
     def process_request(self, req):
-        self.logger.log(f"\n[REQUEST][{req.method}] {req.url}", "info")
+        self.app.logger.log(f"[REQUEST][{req.method}] {req.url}", "info")
 
     def process_response(self, req, res):
-        self.logger.log(f"\n[RESPONSE] {req.url}", "info")
+        self.app.logger.log(f"[RESPONSE] {req.url}", "info")
 
 
 class DefaultExceptionHandler:
